@@ -43,10 +43,14 @@ class AutoIndex(object):
         """Registers a magic module named __autoindex__."""
         app = app or state.app
         if __autoindex__ not in app.blueprints:
+            static_folder = os.path.join(__path__[0], 'static')
             template_folder = os.path.join(__path__[0], 'templates')
-            type(self).shared = Blueprint(__autoindex__, __name__,
-                                          template_folder=template_folder)
-            app.register_blueprint(type(self).shared)
+            shared = Blueprint(__autoindex__, __name__,
+                               template_folder=template_folder)
+            @shared.route('/__autoindex__/<path:filename>')
+            def static(filename):
+                return send_from_directory(static_folder, filename)
+            app.register_blueprint(shared)
 
     def __new__(cls, base, *args, **kwargs):
         if isinstance(base, Flask):
@@ -75,7 +79,7 @@ class AutoIndex(object):
                 return self.render_autoindex(path)
 
     def render_autoindex(self, path, browse_root=None, template=None,
-                         endpoint='autoindex'):
+                         endpoint='.autoindex'):
         """Renders an autoindex with the given path.
 
         :param path: the relative path
@@ -184,18 +188,6 @@ class AutoIndex(object):
         if callable(rule) or callable(icon):
             Entry.add_icon_rule.im_func(self, icon, rule)
 
-    def send_static_file(self, filename):
-        """Serves a static file. It finds the file from autoindex internal
-        static directory first. If it failed to find the file, it finds from
-        the wrapped application or module's static directory.
-        """
-        global_static = os.path.join(os.path.dirname(__file__), 'static')
-        if os.path.isfile(os.path.join(global_static, filename)):
-            static = global_static
-        else:
-            static = os.path.join(self.base.root_path, 'static')
-        return send_from_directory(static, filename)
-
     @property
     def template_prefix(self):
         raise NotImplementedError()
@@ -210,7 +202,6 @@ class AutoIndexApplication(AutoIndex):
         super(AutoIndexApplication, self).__init__(app, browse_root,
                                                    **silk_options)
         self.app = app
-        self.app.view_functions['static'] = self.send_static_file
         self._register_shared_autoindex(app=self.app)
 
 
@@ -225,7 +216,6 @@ class AutoIndexBlueprint(AutoIndex):
                                                  **silk_options)
         self.blueprint = self.base
         self.blueprint.record_once(self._register_shared_autoindex)
-        self.blueprint.send_static_file = self.send_static_file
 
     @cached_property
     def template_prefix(self):
